import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["children", "onSelect", "alwaysRender", "size", "value", "visible"];
import { Children, forwardRef, cloneElement, useState, useEffect, useRef } from 'react';
import useDebounce from '@s-ui/react-hooks/lib/useDebounce';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import isEqual from 'lodash.isequal';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = "sui-MoleculeDropdownList";
var CLASS_HIDDEN = "is-hidden";
var DEBOUNCE_TIME = 500;
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
var MoleculeDropdownList = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var children = _ref.children,
      onSelect = _ref.onSelect,
      alwaysRender = _ref.alwaysRender,
      size = _ref.size,
      value = _ref.value,
      visible = _ref.visible,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var refDropdownList = useRef();
  var ref = useMergeRefs(refDropdownList, forwardedRef);

  var _useState = useState(''),
      typedWord = _useState[0],
      setTypedWord = _useState[1];

  var debouncedTypedWord = useDebounce(typedWord, DEBOUNCE_TIME);
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    var valueChild = child.props.value;
    var selected = false;

    if (Array.isArray(value)) {
      selected = value.some(function (innerValue) {
        return isEqual(valueChild, innerValue);
      });
    } else {
      selected = isEqual(value, valueChild);
    }

    return /*#__PURE__*/cloneElement(child, _extends({}, props, {
      index: index,
      onSelect: onSelect,
      selected: selected
    }));
  });
  var classNames = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_HIDDEN] = !visible, _cx));

  var getFocusedOptionIndex = function getFocusedOptionIndex(options) {
    var currentElementFocused = document.activeElement;
    return Array.from(options).reduce(function (focusedOptionIndex, option, index) {
      if (option === currentElementFocused) focusedOptionIndex = index;
      return focusedOptionIndex;
    }, 0);
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var key = ev.key;
    var options = refDropdownList.current.children;
    var numOptions = options.length;
    var index = getFocusedOptionIndex(options);

    if (key === 'ArrowDown' || key === 'ArrowUp') {
      if (index >= 0 || index <= numOptions) {
        if (key === 'ArrowDown' && index < numOptions - 1) options[index + 1].focus();
        if (key === 'ArrowUp' && index > 0) options[index - 1].focus();
      }
    } else {
      setTypedWord(function (v) {
        return v + key.toLowerCase();
      });
      var word = typedWord + key.toLowerCase();
      var optionToFocusOn = Array.from(options).find(function (option, i) {
        return i >= index && option.innerText.toLowerCase().indexOf(word) === 0;
      }) || Array.from(options).find(function (option) {
        return option.innerText.toLowerCase().indexOf(word) === 0;
      });
      optionToFocusOn && optionToFocusOn.focus();
    }

    ev.preventDefault();
    ev.stopPropagation();
  }; // When DEBOUNCE_TIME reset typed word


  useEffect(function () {
    setTypedWord('');
  }, [debouncedTypedWord]);
  if (!visible && !alwaysRender) return null;
  return /*#__PURE__*/_jsx("ul", {
    ref: ref,
    tabIndex: 0,
    onKeyDown: handleKeyDown,
    className: classNames,
    children: extendedChildren
  });
});
MoleculeDropdownList.displayName = 'MoleculeDropdownList';
MoleculeDropdownList.defaultProps = {
  alwaysRender: true,
  onSelect: function onSelect() {},
  size: SIZES.SMALL
};
export default MoleculeDropdownList;
export { SIZES as moleculeDropdownListSizes };